/**
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of VLTD (Voltage Detection Circuit) demo
 *          for the TOSHIBA 'TMPM3U0' Device Series
 * @version V0.101
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *******************************************************************************
 */

#include "tmpm3u0_cg.h"
#include "tmpm3u0_gpio.h"
#include "tmpm3u0_vltd.h"
#include "tmpm3u0_wdt.h"

int main(void)
{
    WDT_Disable();                        /* Disable WDT explicitly */
    GPIO_SetOutput(GPIO_PG, GPIO_BIT_0);  /* Set PG0 as output port */

    if (CG_GetResetFlag().Bit.VLTDReset == 0U) {
        VLTD_SetVoltage(VLTD_DETECT_VOLTAGE_46);  /* change the parameter to select
                                                     different detection voltage */
        VLTD_Enable();                    /* Enable VLTD function */
        GPIO_WriteData(GPIO_PG, 0x00U);    /* Set PG0 to LOW */
    } else {
        VLTD_Disable();                   /* Disable VLTD function */
        GPIO_WriteData(GPIO_PG, 0x01U);    /* Set PG0 to HIGH */
    }

    while (1U) {
        /* Do nothing */
    }
}

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1U) {
        __NOP();
    }
}
#endif
